@@ -1,11 +1,11 @@
 
 from .reflection import Reflect, VersionReflect
 from .call import Call, VersionCall
-from .exception import CallError, Redirect 
+from .exception import CallError, Redirect, CallStop
 from .http import Request, Response
 from .utils import AcceptHeader
 from .core import Controller, CorsMixin
 from . import decorators
 
-__version__ = '0.7.8'
+__version__ = '0.7.9'
 
